Class: Google::Ads::MarketingPlatform::Admin::V1alpha::AnalyticsAccountLink

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/marketingplatform/admin/v1alpha/resources.rb

Overview

A resource message representing the link between a Google Analytics account and a Google Marketing Platform organization.

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_account ⇒ ::String



62
63
64
65
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 62

class AnalyticsAccountLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name ⇒ ::String (readonly)



62
63
64
65
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 62

class AnalyticsAccountLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end


62
63
64
65
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 62

class AnalyticsAccountLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name ⇒ ::String



62
63
64
65
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 62

class AnalyticsAccountLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end