Class: Google::Ads::MarketingPlatform::Admin::V1alpha::UpdateAdminAccessBindingRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/marketingplatform/admin/v1alpha/marketingplatform_admin.rb

Overview

Request message for UpdateAdminAccessBinding RPC.

Instance Attribute Summary collapse

Instance Attribute Details

#admin_access_binding ⇒ ::Google::Ads::MarketingPlatform::Admin::V1alpha::AdminAccessBinding

Returns Required. The AdminAccessBinding to update.

Returns:



522
523
524
525
# File 'proto_docs/google/marketingplatform/admin/v1alpha/marketingplatform_admin.rb', line 522

class UpdateAdminAccessBindingRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask ⇒ ::Google::Protobuf::FieldMask

Returns Required. The list of fields to update. Field names must be in snake case (for example, "field_to_update"). Omitted fields will not be updated. To replace the entire entity, use one path with the string "*" to match all fields.

Returns:

  • (::Google::Protobuf::FieldMask) —

    Required. The list of fields to update. Field names must be in snake case (for example, "field_to_update"). Omitted fields will not be updated. To replace the entire entity, use one path with the string "*" to match all fields.



522
523
524
525
# File 'proto_docs/google/marketingplatform/admin/v1alpha/marketingplatform_admin.rb', line 522

class UpdateAdminAccessBindingRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end