Class: Google::Ads::MarketingPlatform::Admin::V1alpha::UpdateUserGroupMemberRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/marketingplatform/admin/v1alpha/marketingplatform_admin.rb

Overview

Request message for UpdateUserGroupMember RPC.

Instance Attribute Summary collapse

Instance Attribute Details

#update_mask ⇒ ::Google::Protobuf::FieldMask

Returns Required. The list of fields to update. Field names must be in snake case (for example, "field_to_update"). Omitted fields will not be updated. To replace the entire entity, use one path with the string "*" to match all fields.

Returns:

  • (::Google::Protobuf::FieldMask) —

    Required. The list of fields to update. Field names must be in snake case (for example, "field_to_update"). Omitted fields will not be updated. To replace the entire entity, use one path with the string "*" to match all fields.



432
433
434
435
# File 'proto_docs/google/marketingplatform/admin/v1alpha/marketingplatform_admin.rb', line 432

class UpdateUserGroupMemberRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_group_member ⇒ ::Google::Ads::MarketingPlatform::Admin::V1alpha::UserGroupMember

Returns Required. The user group member to update.

Returns:



432
433
434
435
# File 'proto_docs/google/marketingplatform/admin/v1alpha/marketingplatform_admin.rb', line 432

class UpdateUserGroupMemberRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end