Class: Google::Ads::MarketingPlatform::Admin::V1alpha::AdminAccessBinding

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/marketingplatform/admin/v1alpha/resources.rb

Overview

A resource message representing a binding to a set of roles.

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ ::String

Returns Identifier. The resource name of this AdminAccessBinding.

Format: organizations/{org_id}/adminAccessBindings/{admin_access_binding_id} Example: "organizations/123abc/adminAccessBindings/456def".

Returns:

  • (::String) —

    Identifier. The resource name of this AdminAccessBinding.

    Format: organizations/{org_id}/adminAccessBindings/{admin_access_binding_id} Example: "organizations/123abc/adminAccessBindings/456def"



150
151
152
153
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 150

class AdminAccessBinding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#organization_roles ⇒ ::Array<::Google::Ads::MarketingPlatform::Admin::V1alpha::OrganizationRole>

Returns Optional. A list of roles granted to the parent organization.

USER_ADMIN_ROLE and BILLING_ADMIN_ROLE will be automatically added if ORG_ADMIN_ROLE is assigned.

No roles will be assigned if no roles are specified.

Returns:



150
151
152
153
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 150

class AdminAccessBinding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_email ⇒ ::String

Returns Email address of the user.

Note: The following fields are mutually exclusive: user_email, user_group. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String) —

    Email address of the user.

    Note: The following fields are mutually exclusive: user_email, user_group. If a field in that set is populated, all other fields in the set will automatically be cleared.



150
151
152
153
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 150

class AdminAccessBinding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_group ⇒ ::String

Returns Resource name of the user group.

Note: The following fields are mutually exclusive: user_group, user_email. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String) —

    Resource name of the user group.

    Note: The following fields are mutually exclusive: user_group, user_email. If a field in that set is populated, all other fields in the set will automatically be cleared.



150
151
152
153
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 150

class AdminAccessBinding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end