Module: Google::Ads::MarketingPlatform::Admin::V1alpha::OrganizationRole
- Defined in:
- proto_docs/google/marketingplatform/admin/v1alpha/resources.rb
Overview
Roles that can be assigned to a user or user group in a GMP organization.
Constant Summary collapse
- ORGANIZATION_ROLE_UNSPECIFIED =
Unknown or unspecified organization role.
0- ORG_ADMIN_ROLE =
Organization admin role that grants all administrative privileges.
1- USER_ADMIN_ROLE =
User admin role that grants access to the Users section to perform various user management functions.
2- BILLING_ADMIN_ROLE =
Billing admin role that grants access to the Billing section to perform various billing-related functions.
3