Class: Google::Ads::MarketingPlatform::Admin::V1alpha::UserGroupMember
- Inherits:
-
Object
- Object
- Google::Ads::MarketingPlatform::Admin::V1alpha::UserGroupMember
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/marketingplatform/admin/v1alpha/resources.rb
Overview
A resource message representing a member of a user group.
Defined Under Namespace
Modules: MembershipRole
Instance Attribute Summary collapse
-
#membership_role ⇒ ::Google::Ads::MarketingPlatform::Admin::V1alpha::UserGroupMember::MembershipRole
Optional.
-
#name ⇒ ::String
Identifier.
-
#user_email ⇒ ::String
Email address of the user member.
-
#user_group ⇒ ::String
User group resource name of the group member.
Instance Attribute Details
#membership_role ⇒ ::Google::Ads::MarketingPlatform::Admin::V1alpha::UserGroupMember::MembershipRole
Returns Optional. The role of the member in the user group.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 107 class UserGroupMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The role of the member in the user group. module MembershipRole # Unspecified membership role. MEMBERSHIP_ROLE_UNSPECIFIED = 0 # Owner role that can add and remove group members. MEMBERSHIP_ROLE_OWNER = 1 # Member role that receives all permissions assigned to the group. MEMBERSHIP_ROLE_MEMBER = 2 end end |
#name ⇒ ::String
Returns Identifier. The resource name of this UserGroupMember.
Format: organizations/{org_id}/userGroups/{user_group_id}/members/{member_id} Example: "organizations/123abc/userGroups/456def/members/789ghi".
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 107 class UserGroupMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The role of the member in the user group. module MembershipRole # Unspecified membership role. MEMBERSHIP_ROLE_UNSPECIFIED = 0 # Owner role that can add and remove group members. MEMBERSHIP_ROLE_OWNER = 1 # Member role that receives all permissions assigned to the group. MEMBERSHIP_ROLE_MEMBER = 2 end end |
#user_email ⇒ ::String
Returns Email address of the user member.
Note: The following fields are mutually exclusive: user_email, user_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 107 class UserGroupMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The role of the member in the user group. module MembershipRole # Unspecified membership role. MEMBERSHIP_ROLE_UNSPECIFIED = 0 # Owner role that can add and remove group members. MEMBERSHIP_ROLE_OWNER = 1 # Member role that receives all permissions assigned to the group. MEMBERSHIP_ROLE_MEMBER = 2 end end |
#user_group ⇒ ::String
Returns User group resource name of the group member.
Note: The following fields are mutually exclusive: user_group, user_email. If a field in that set is populated, all other fields in the set will automatically be cleared.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'proto_docs/google/marketingplatform/admin/v1alpha/resources.rb', line 107 class UserGroupMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The role of the member in the user group. module MembershipRole # Unspecified membership role. MEMBERSHIP_ROLE_UNSPECIFIED = 0 # Owner role that can add and remove group members. MEMBERSHIP_ROLE_OWNER = 1 # Member role that receives all permissions assigned to the group. MEMBERSHIP_ROLE_MEMBER = 2 end end |